# invoke with "--with tests" to enable tests, currently disabled
# as we need to package both wsgi_intercept and pytest-localserver
# for them to work. Will also need BR: pystest once the two
# above packages exist in Fedora

%bcond_with tests
%if 0%{?fedora}
%bcond_without python3
%else
%bcond_with python3
%endif

%global sum Synchronize calendars and contacts
%global srcname vdirsyncer
# Share doc between python- and python3-
%global _docdir_fmt %{name}

Name:       vdirsyncer
Version:    0.11.0
Release:    1%{?git_tag}%{?dist}
Summary:    %{sum}

License:    MIT
URL:        https://github.com/untitaker/%{name}
Source0:    https://pypi.python.org/packages/39/e5/1e7097b5f0cd6de79ec9014f162a6000b77ca2a369ea8a1588a2eebff570/%{name}-%{version}.tar.gz
BuildArch:  noarch

BuildRequires:  python-atomicwrites
BuildRequires:  python-click
BuildRequires:  python2-click-log
BuildRequires:  python2-click-threading
BuildRequires:  python2-devel
BuildRequires:  python-icalendar
BuildRequires:  python-lxml
BuildRequires:  python2-requests
BuildRequires:  python2-setuptools
BuildRequires:  python2-setuptools_scm
BuildRequires:  python2-sphinx
BuildRequires:  python2-sphinx_rtd_theme
BuildRequires:  python2-sphinx_rtd_theme

%if %{with python3}
BuildRequires:  python3-atomicwrites
BuildRequires:  python3-click
BuildRequires:  python3-click-log
BuildRequires:  python3-click-threading
BuildRequires:  python3-devel
BuildRequires:  python3-icalendar
BuildRequires:  python3-lxml
BuildRequires:  python3-requests
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  python3-sphinx_rtd_theme
%endif

%if %{with python3}
Requires:       python3-atomicwrites >= 0.1.7
Requires:       python3-click >= 5.0
Requires:       python3-click-log >= 0.1.3
Requires:       python3-click-threading >= 0.1.2
Requires:       python3-icalendar
Requires:       python3-lxml >= 3.1
Requires:       python3-requests >= 2.4.1
Requires:       python3-requests-toolbelt >= 0.4.0
Requires:       python3-vdirsyncer = 0.11.0
%endif

%description
vdirsyncer synchronizes your calendars and address books between two entities.
The supported protocols are CalDAV, CardDAV, arbitrary HTTP resources and some
more.

It aims to be for CalDAV and CardDAV what OfflineIMAP is for IMAP.

%package -n python2-%{srcname}
Summary:        %{sum}
%{?python_provide:%python_provide python2-%{srcname}}

Requires:       python-atomicwrites >= 0.1.7
Requires:       python-click >= 5.0
Requires:       python2-click-log >= 0.1.3
Requires:       python2-click-threading >= 0.1.2
Requires:       python-icalendar
Requires:       python-lxml >= 3.1
Requires:       python2-requests >= 2.4.1
Requires:       python2-requests-toolbelt >= 0.4.0

%description -n python2-%{srcname}
vdirsyncer synchronizes your calendars and address books between two entities.
The supported protocols are CalDAV, CardDAV, arbitrary HTTP resources and some
more.

It aims to be for CalDAV and CardDAV what OfflineIMAP is for IMAP.
This package contains the python2 modules.

%package -n python3-%{srcname}
Summary:        %{sum}
%{?python_provide:%python_provide python3-%{srcname}}

%if %{with python3}
Requires:       python3-atomicwrites >= 0.1.7
Requires:       python3-click >= 5.0
Requires:       python3-click-log >= 0.1.3
Requires:       python3-click-threading >= 0.1.2
Requires:       python3-icalendar
Requires:       python3-lxml >= 3.1
Requires:       python3-requests >= 2.4.1
Requires:       python3-requests-toolbelt >= 0.4.0
%endif

%description -n python3-%{srcname}
vdirsyncer synchronizes your calendars and address books between two entities.
The supported protocols are CalDAV, CardDAV, arbitrary HTTP resources and some
more.

It aims to be for CalDAV and CardDAV what OfflineIMAP is for IMAP.
This package contains the python3 modules.

%package doc
Summary:        Documentation for vdirsyncer

%description doc
The vdirsyncer-doc package provides all the documentation
for the vdirsyncer calendar/address-book synchronization utility.

%prep
%setup -q
#%patch0 -p1 -b .no-scm

%if %{with python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
%endif

%build
%py2_build
# Custom sphinx docs need to import vdirsyncer classes from the untarred
# source tree
export PYTHONPATH=`pwd`
cd docs
# NOT using smp_mflags because sphinx cannot really cope with it
# i.e. one out of 20 builds will misteriously fail
make SPHINXBUILD=sphinx-build-3 man html text
cd ..
unset PYTHONPATH
# Remove extra copy of text docs
rm -vrf docs/_build/html/_sources
rm -fv docs/_build/html/{.buildinfo,objects.inv}

%if %{with python3}
pushd %{py3dir}
%py3_build
popd
%endif


%install
%py2_install
%if %{with python3}
pushd %{py3dir}
%py3_install
popd
%endif

install -d "$RPM_BUILD_ROOT%{_mandir}/man1"
cp -r docs/_build/man/%{name}.1 "$RPM_BUILD_ROOT%{_mandir}/man1"

%check
%if %{with tests}
sh build.sh tests
%endif

%files -n python2-%{srcname}
%license LICENSE
%doc AUTHORS.rst README.rst CONTRIBUTING.rst
%{python2_sitelib}/*
# If you need the vdirsyncer CLI install the python3 variant
#%{_bindir}/vdirsyncer
%{_mandir}/man1/%{name}.1.*

%files -n python3-%{srcname}
%license LICENSE
%doc AUTHORS.rst README.rst CONTRIBUTING.rst
%{python3_sitelib}/*

%files
%license LICENSE
%{_bindir}/vdirsyncer
%{_mandir}/man1/%{name}.1.*

# Still one rpmlint warning due to BZ 1107813
# W: wrong-file-end-of-line-encoding /usr/share/doc/vdirsyncer-doc/html/_static/jquery.js
%files doc
%doc docs/_build/html docs/_build/text

%changelog
* Sun May 22 2016 Michele Baldessari <michele@acksyn.org> - 0.11.0-1
- New upstream (BZ#1329867)
- Split the package in python{2,3}-vdirsyncer containing the python modules and
  vdirsyncer containing the binary (needs the python3-modules)
- Add a python2 vdirsyncer module (BZ#1323555)

* Tue May 03 2016 Michele Baldessari <michele@acksyn.org> - 0.10.0-1
- New upstream

* Wed Mar 23 2016 Michele Baldessari <michele@acksyn.org> - 0.9.3-1
- New upstream

* Mon Mar 14 2016 Michele Baldessari <michele@acksyn.org> - 0.9.2-1
- New upstream
- Fix up some requires versioning

* Tue Feb 16 2016 Michele Baldessari <michele@acksyn.org> - 0.9.0-1
- New upstream

* Sat Feb 13 2016 Michele Baldessari <michele@acksyn.org> - 0.8.1-2
- Switch to python3 by default

* Fri Feb 12 2016 Michele Baldessari <michele@acksyn.org> - 0.8.1-1
- New upstream (requires python-click-{log,threading})

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jan 24 2016 Michele Baldessari <michele@acksyn.org> - 0.7.5-1
- New upstream, requires 0.5.0 python-requests-toolbelt

* Sat Nov 28 2015 Michele Baldessari <michele@acksyn.org> - 0.7.3-1
- New upstream (BZ 1275860)

* Sun Sep 13 2015 Michele Baldessari <michele@acksyn.org> - 0.6.0-2
- Add python-atomicwrites requires (BZ 1262597)

* Thu Aug 06 2015 Ben Boeckel <mathstuf@gmail.com> - 0.6.0-1
- Update to 0.6.0
- Use %%license
- Use PyPI tarball (see setup.py)

* Mon Jul 06 2015 Michele Baldessari <michele@acksyn.org> - 0.5.2-2
- Fix FTBFS (BZ#1046338)
* Tue Jun 16 2015 Michele Baldessari <michele@acksyn.org> - 0.5.2-1
- Update to 0.5.2
- Drop doc build patch
* Wed Jun 03 2015 Michele Baldessari <michele@acksyn.org> - 0.5.1-1
- Update to 0.5.1
- Drop system-urllib3.patch

* Fri Mar 13 2015 Michele Baldessari <michele@acksyn.org> - 0.4.4-1
- Update to 0.4.4

* Mon Mar 02 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-5
- Disable python3 for now until khal supports it

* Sun Mar 01 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-4
- Port to python3

* Sun Mar 01 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-3
- Split out a -doc subpackage as fedora-review complained

* Sat Feb 28 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-2
- Conditional test builds

* Mon Feb 23 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-1
- New upstream

* Wed Feb 11 2015 Michele Baldessari <michele@redhat.com> - 0.4.2-3
- Add html and text documentation

* Wed Feb 04 2015 Michele Baldessari <michele@redhat.com> - 0.4.2-2
- Add python-atomicwrites dependency

* Tue Feb 03 2015 Michele Baldessari <michele@redhat.com> - 0.4.2-1
- New upstream

* Mon Jan 05 2015 Michele Baldessari <michele@redhat.com> - 0.4.0-2
- Force use of system urllib3

* Mon Jan 05 2015 Michele Baldessari <michele@redhat.com> - 0.4.0-1
- New upstream

* Mon Jan 05 2015 Michele Baldessari <michele@redhat.com> - 0.3.4-2
- Added python-icalendar and python-click Requires

* Mon Dec 15 2014 Michele Baldessari <michele@redhat.com> - 0.3.4-1
- New upstream

* Wed Oct 01 2014 Michele Baldessari <michele@redhat.com> - 0.3.0-1
- Initial packaging
